/*
{*******************************************************************}
{                                                                   }
{       KS.CRM                                                      }
{       Customer Relationship Management                            }
{                                                                   }
{       Copyright (c) 2002 - 2013 by Kroll-Software                 }
{       All Rights Reserved                                         }
{                                                                   }
{   This code is provided 'as is',                                  }
{   without warranties of any kind. Use at your own risk.           }
{                                                                   }
{   You need a KS.CRM source-code license in order to use           }
{   these sources or portions of it.                                }
{                                                                   }
{   You must not publish, redistribute or transfer                  }
{   this source code to 3rd parties under any conditions.           }
{                                                                   }
{*******************************************************************}
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using KS.Common;
using KS.CRM.UI;
using KS.CRM.UI.Extensions;

namespace KS.CRM.Favorites
{
    internal class GridViewFavorites : GridDataView
    {        
        public override string Caption
        {
            get
            {
                return Properties.Resources.NavControlViewMyFavorites;
            }
        }

        public override string LoadingStatusMessage
        {
            get
            {
                return Properties.Resources.GridViewStatusLoadingFavorites;
            }
        }

        protected ImageList m_ImlPlugIns = null;
        public ImageList ImlPlugIns
        {
            get
            {
                return m_ImlPlugIns;
            }
        }

        public GridViewFavorites(KS.CRM.Base.CrmDatabase DB, KS.CRM.UI.CrmGrid KSGrid, ucCategories CategoryControl)
            : base(DB, KSGrid, CategoryControl)
        {
            QueryManager.TableName = "vwFavorites";
            QueryManager.DefaultOrderBy = "changed Desc";
            //SqlQuery.PrimaryKeyColumnName = "";

            m_ImlPlugIns = new ImageList();
            m_ImlPlugIns.ColorDepth = ColorDepth.Depth32Bit;
            LoadImageList();

            m_DB.StateChanged += new EventHandler(m_DB_StateChanged);
        }

        void m_DB_StateChanged(object sender, EventArgs e)
        {
            if (m_DB.IsConnected)
            {
                LoadImageList();
            }
        }

        private void LoadImageList()
        {
            if (m_DB.PlugIns != null)
            {
                m_ImlPlugIns.Images.Clear();

                KS.CRM.PlugIn.IKSCRMPlugIn PlugIn = null;
                foreach (object o in m_DB.PlugIns)
                {
                    PlugIn = (KS.CRM.PlugIn.IKSCRMPlugIn)o;
                    m_ImlPlugIns.Images.Add(PlugIn.Key, PlugIn.SmallIcon);
                }
            }
        }

        protected override string AreaWhere()
        {            
            return "(UserID=" + m_DB.UserID.ToString() + ")";
        }

        protected override string CategoriesSelect(string strID)
        {
            if (strID == "")
                return "";
            else
                return "(EXISTS (select CategoryID from Category2Favorite WHERE (CategoryID IN (" + strID + ")) AND (RefID=ID)))";
        }

        public override void LoadData(bool bRefetch)
        {            
            base.LoadData(bRefetch);
        }

        public override void SetColumns()
        {
            this.AddIntegerColumn("UserID", "UserID", 80, false);
            this.AddIntegerColumn("TableID", "TableID", 80, false);
            this.AddIntegerColumn("RefID", "RefID", 80, false);
            this.AddTextColumn("PlugInKey", "PlugInKey", 80, false);

            KS.CRM.UI.Controls.DataGridViewImageTextColumn colTitle = new UI.Controls.DataGridViewImageTextColumn();
            colTitle.Name = "DisplayName";            
            colTitle.HeaderText = Properties.Resources.ColumnDisplayName;
            //colTitle.DataPropertyName = Properties.Resources.ColumnTitle;
            colTitle.DataPropertyName = "Title";
            colTitle.AutoSizeMode = DataGridViewAutoSizeColumnMode.Fill;
            colTitle.ImageList = m_ImlPlugIns;
            m_CrmGrid.GRD.Columns.Add(colTitle);

            //AddStandardColumn("Title", "Title", "Title", 240, true);
            //pKSGrid.GRD.Columns["Title"].AutoSizeMode = System.Windows.Forms.DataGridViewAutoSizeColumnMode.Fill;

            this.AddTextColumn("Description", Properties.Resources.ColumnDescription, 240, false);

            this.AddDateTimeColumn("created", Properties.Resources.ColumnCreated, true);
            this.AddDateTimeColumn("changed", Properties.Resources.ColumnChanged, false);
        }

        public override CrmSearchFormBase GetNewSearchForm()
        {            
            return new FavoriteSearch();            
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                m_DB.StateChanged -= new EventHandler(m_DB_StateChanged);

                if (m_ImlPlugIns != null)
                {
                    m_ImlPlugIns.Dispose();
                    m_ImlPlugIns = null;
                }
            }

            base.Dispose(disposing);
        }
    }
}
